aboutsummaryrefslogtreecommitdiffstats
path: root/engine/items/tmhm.asm
diff options
context:
space:
mode:
authoryenatch <yenatch@gmail.com>2014-05-26 14:04:56 -0700
committeryenatch <yenatch@gmail.com>2014-05-26 22:04:39 -0700
commit40c17c906b2b3f65b3b04b1933b90238a7ac5566 (patch)
tree6de26c959808d5a792b692f2300c33557c1dbfab /engine/items/tmhm.asm
parentDon't hardcode wram sections (except for alignment). (diff)
downloadpokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.tar.gz
pokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.tar.xz
pokeyellow-40c17c906b2b3f65b3b04b1933b90238a7ac5566.zip
Remove most static wram addresses. Use labels instead.
For unknown addresses, use "w<address>". Label overleads are still an issue.
Diffstat (limited to 'engine/items/tmhm.asm')
-rwxr-xr-xengine/items/tmhm.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/items/tmhm.asm b/engine/items/tmhm.asm
index 5b7b4e8e..20e5786b 100755
--- a/engine/items/tmhm.asm
+++ b/engine/items/tmhm.asm
@@ -1,10 +1,10 @@
; checks if the mon in wWhichPokemon already knows the move in $d0e0
CheckIfMoveIsKnown: ; 2fe18 (b:7e18)
ld a, [wWhichPokemon]
ld hl, W_PARTYMON1_MOVE1
ld bc, $2c
call AddNTimes
- ld a, [$d0e0]
+ ld a, [wd0e0]
ld b, a
ld c, $4 ; nubmer of moves
.loop
@@ -1,10 +1,10 @@
-; checks if the mon in wWhichPokemon already knows the move in $d0e0
+; checks if the mon in wWhichPokemon already knows the move in wd0e0
CheckIfMoveIsKnown: ; 2fe18 (b:7e18)
ld a, [wWhichPokemon]